declare enum Level {
    ERROR = "ERROR",
    WARNING = "WARNING",
    INFO = "INFO",
    DEBUG = "DEBUG"
}
declare enum Domain {
    TOOL = "TOOL",
    AGENT = "AGENT",
    MCP = "MCP",
    UNKNOWN = "UNKNOWN"
}
declare enum ErrorCategory {
    UNKNOWN = "UNKNOWN",
    USER = "USER",
    SYSTEM = "SYSTEM"
}
type Scalar = null | boolean | number | string;
type Json<T> = [T] extends [Scalar | undefined] ? Scalar : [T] extends [{
    [x: number]: unknown;
}] ? {
    [K in keyof T]: Json<T[K]>;
} : never;
/**
 * Defines the structure for an error's metadata.
 * This is used to create instances of MastraError.
 */
interface IErrorDefinition {
    /** Unique identifier for the error. */
    id: string | number;
    /**
     * The error message template or a function to generate it.
     * If a function, it receives context to interpolate values.
     */
    text: string;
    /**
     * Functional domain of the error (e.g., CONFIG, BUILD, API).
     */
    domain: `${Domain}`;
    /** Broad category of the error (e.g., USER, SYSTEM, THIRD_PARTY). */
    category: `${ErrorCategory}`;
    details?: Record<string, Json<Scalar>>;
}
/**
 * Base error class for the Mastra ecosystem.
 * It standardizes error reporting and can be extended for more specific error types.
 */
declare class MastraError extends Error {
    readonly id: string | number;
    readonly domain: `${Domain}`;
    readonly category: `${ErrorCategory}`;
    readonly originalError?: Error;
    readonly details?: Record<string, Json<Scalar>>;
    constructor(errorDefinition: IErrorDefinition, originalError?: Error | MastraError);
    /**
     * Returns a structured representation of the error, useful for logging or API responses.
     */
    toJSONDetails(): {
        message: string;
        domain: "TOOL" | "AGENT" | "MCP" | "UNKNOWN";
        category: "UNKNOWN" | "USER" | "SYSTEM";
        stack: string | undefined;
        originalError: Error | undefined;
        details: Record<string, Scalar> | undefined;
    };
    toJSON(): {
        message: string;
        details: {
            message: string;
            domain: "TOOL" | "AGENT" | "MCP" | "UNKNOWN";
            category: "UNKNOWN" | "USER" | "SYSTEM";
            stack: string | undefined;
            originalError: Error | undefined;
            details: Record<string, Scalar> | undefined;
        };
        code: string | number;
    };
}

export { Domain, ErrorCategory, type IErrorDefinition, Level, MastraError };
